@@ -4,7 +4,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief internal context structures and functions
  *
- * Copyright (c) 2015 - 2023 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2024 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -56,7 +56,7 @@ struct lys_module;
  * by a custom  module searching callback (::ly_module_imp_clb) set via ::ly_ctx_set_module_imp_clb(). The algorithm of
  * searching in search dirs is also available via API as ::lys_search_localfile() function.
  *
- * YANG modules are added into the context using [parser functions](@ref howtoSchemaParsers) - \b lys_parse*().
+ * YANG modules are added into the context using [parser functions](@ref howtoSchemaParsers) - @b lys_parse*().
  * Alternatively, also ::ly_ctx_load_module() can be used - in that case the ::ly_module_imp_clb or automatic
  * search in search directories and in the current working directory is used, as described above. YANG submodules cannot be loaded
  * or even validated directly, they are loaded always only as includes of YANG modules. Explicitly parsed/loaded modules are
@@ -76,17 +76,37 @@ struct lys_module;
  *
  * Context holds all the schema modules internally. To get a specific module, use ::ly_ctx_get_module() (or some of its
  * variants). If you need to do something with all the modules in the context, it is advised to iterate over them using
- * ::ly_ctx_get_module_iter(). Alternatively, the ::ly_ctx_get_yanglib_data() function can be used to get complex information about the schemas in the context
- * in the form of data tree defined by <a href="https://tools.ietf.org/html/rfc7895">ietf-yang-library</a> module.
+ * ::ly_ctx_get_module_iter(). Alternatively, the ::ly_ctx_get_yanglib_data() function can be used to get complex
+ * information about the schemas in the context in the form of data tree defined by
+ * <a href="https://tools.ietf.org/html/rfc7895">ietf-yang-library</a> module.
  *
- * YANG data can be parsed by \b lyd_parse_*() functions. Note, that functions for schema have \b lys_
- * prefix (or \b lysp_ for the parsed and \b lysc_ for the compiled schema - for details see @ref howtoSchema page) while
+ * YANG data can be parsed by @b lyd_parse_*() functions. Note, that functions for schema have @b lys_
+ * prefix (or @b lysp_ for the parsed and @b lysc_ for the compiled schema - for details see @ref howtoSchema page) while
  * functions for instance data have \b lyd_ prefix. Details about data formats or handling data without the appropriate
  * YANG module in context can be found on @ref howtoData page.
  *
  * Besides the YANG modules, context holds also [error information](@ref howtoErrors) and
  * [database of strings](@ref howtoContextDict), both connected with the processed YANG modules and data.
  *
+ * @section howtoPrintedContext Printed Context
+ *
+ * Having a context, it is possible to print (serialize) it into a continuous memory chunk presumably obtained from
+ * `mmap(2)` call. Note that only the **compiled** context is printed so no parsed modules are stored and, once written,
+ * it cannot be changed and is **immutable** and read-only. Calling ::ly_ctx_compiled_size() returns the final size
+ * of the context and ::ly_ctx_compiled_print() will actually print it. Then, the memory can be passed to
+ * ::ly_ctx_new_printed() that will return the standard context structure directly using the printed structures and
+ * creating only the required writable run-time data. Note that for the context printed by one process to be used
+ * by another process (or even the same after it restarts), the absolute address returned by `mmap(2)` **must be** the
+ * **exact same** as the one used for printing for the context to be valid and usable.
+ *
+ * As mentioned, the printed context includes only the compiled modules and hence certain functions may return an error
+ * if such a context is passed as their parameter. Most notably, they are functions related to modifying the context
+ * (changing search directories, adding new modules, ...) and accessing YANG features. It is also possible to free the
+ * parsed modules of a standard context to free up some memory using ::ly_ctx_free_parsed().
+ *
+ * Other than that, the printed context is not restricted in its use or functionality compared to a standard context.
+ * It can be shared between several processes and threads safely, each having their own error queue.
+ *
  * - @subpage howtoErrors
  * - @subpage howtoContextDict
  *
@@ -196,17 +216,30 @@ struct ly_ctx;
 #define LY_CTX_ENABLE_IMP_FEATURES 0x0100 /**< By default, all features of newly implemented imported modules of
                                         a module that is being loaded are disabled. With this flag they all become
                                         enabled. */
-#define LY_CTX_LEAFREF_EXTENDED 0x0200 /**< By default, path attribute of leafref accepts only path as defined in RFC 7950.
+#define LY_CTX_COMPILE_OBSOLETE 0x0200  /**< Obsolete nodes are normally not compiled into the compiled schema. This
+                                        flag changes the behavior to include them so they can be created and validated
+                                        just like current and deprecated nodes. */
+#define LY_CTX_LYB_HASHES 0x0400 /**< Generate hashes for all the schema nodes. Required when using LYB data parse
+                                        or print. */
+#define LY_CTX_LEAFREF_EXTENDED 0x0800 /**< By default, path attribute of leafref accepts only path as defined in RFC 7950.
                                         By using this option, the path attribute will also allow using XPath functions as deref() */
-#define LY_CTX_LEAFREF_LINKING 0x0400 /**< Link valid leafref nodes with its target during validation if leafref node is not using
+#define LY_CTX_LEAFREF_LINKING 0x1000 /**< Link valid leafref nodes with its target during validation if leafref node is not using
                                         'require-instance false;'. It also enables usage of
                                         [lyd_leafref_get_links](@ref lyd_leafref_get_links) and
                                         [lyd_leafref_link_node_tree](@ref lyd_leafref_link_node_tree) APIs. */
-#define LY_CTX_BUILTIN_PLUGINS_ONLY 0x0800 /**< By default, context uses all available plugins for types and extensions,
-                                        both included and external. This options prevents all included plugins to be
-                                        loaded except for built-in YANG types so all derived types will use these and
-                                        for all purposes behave as the base type. The option can be used for cases when
-                                        invalid data needs to be stored in YANG node values. */
+#define LY_CTX_BUILTIN_PLUGINS_ONLY 0x2000 /**< Limits the context to use only built-in YANG type plugins,
+                                        treating all derived types as their base type.
+                                        Useful for storing invalid data in YANG node values.
+                                        This option has a global effect: the global plugin array is initialized only when no contexts exist.
+                                        If any context was created without this flag and is still alive,
+                                        creating a new context with this flag will not have the intended effect. */
+#define LY_CTX_STATIC_PLUGINS_ONLY 0x4000 /**< Restricts the context to load only static (built-in) plugins,
+                                        ignoring external plugins from directories specified by `LIBYANG_TYPES_PLUGINS_DIR` and
+                                        `LIBYANG_EXTENSIONS_PLUGINS_DIR`. This option has a global effect: the global plugin array
+                                        is initialized only when no contexts exist. If any context was created without this flag
+                                        and is still alive, creating a new context with this flag will not have the intended effect. */
+
+/* 0x80000000 reserved for internal use */
 
 /** @} contextoptions */
 
@@ -232,7 +265,7 @@ struct ly_ctx;
  * @param[out] new_ctx Pointer to the created libyang context if LY_SUCCESS returned.
  * @return LY_ERR return value.
  */
-LIBYANG_API_DECL LY_ERR ly_ctx_new(const char *search_dir, uint16_t options, struct ly_ctx **new_ctx);
+LIBYANG_API_DECL LY_ERR ly_ctx_new(const char *search_dir, uint32_t options, struct ly_ctx **new_ctx);
 
 /**
  * @brief Create libyang context according to the provided yang-library data in a file.
@@ -283,7 +316,7 @@ LIBYANG_API_DECL LY_ERR ly_ctx_new_ylmem(const char *search_dir, const char *dat
  *
  * @param[in] search_dir Directory where libyang will search for the imported or included modules and submodules.
  * If no such directory is available, NULL is accepted.
- * @param[in] tree Data tree containing yang-library data.
+ * @param[in] tree Data tree pointing to the 'yang-library' data.
  * @param[in] options Context options, see @ref contextoptions.
  * @param[in,out] ctx If *ctx is not NULL, the existing libyang context is modified.  Otherwise, a pointer to a
  * newly created context is returned here if LY_SUCCESS.
@@ -352,7 +385,7 @@ LIBYANG_API_DECL const char * const *ly_ctx_get_searchdirs(const struct ly_ctx *
  * @param[in] ctx Context to query.
  * @return Combination of all the currently set context's options, see @ref contextoptions.
  */
-LIBYANG_API_DECL uint16_t ly_ctx_get_options(const struct ly_ctx *ctx);
+LIBYANG_API_DECL uint32_t ly_ctx_get_options(const struct ly_ctx *ctx);
 
 /**
  * @brief Set some of the context's options, see @ref contextoptions.
@@ -362,7 +395,7 @@ LIBYANG_API_DECL uint16_t ly_ctx_get_options(const struct ly_ctx *ctx);
  * and all ::lysc_node.priv in the modules will be overwritten, see ::LY_CTX_SET_PRIV_PARSED.
  * @return LY_ERR value.
  */
-LIBYANG_API_DECL LY_ERR ly_ctx_set_options(struct ly_ctx *ctx, uint16_t option);
+LIBYANG_API_DECL LY_ERR ly_ctx_set_options(struct ly_ctx *ctx, uint32_t option);
 
 /**
  * @brief Unset some of the context's options, see @ref contextoptions.
@@ -370,7 +403,7 @@ LIBYANG_API_DECL LY_ERR ly_ctx_set_options(struct ly_ctx *ctx, uint16_t option);
  * @param[in] option Combination of the context's options to be unset, see @ref contextoptions.
  * @return LY_ERR value.
  */
-LIBYANG_API_DECL LY_ERR ly_ctx_unset_options(struct ly_ctx *ctx, uint16_t option);
+LIBYANG_API_DECL LY_ERR ly_ctx_unset_options(struct ly_ctx *ctx, uint32_t option);
 
 /**
  * @brief Get the change count of the context (module set) during its life-time.
@@ -381,11 +414,10 @@ LIBYANG_API_DECL LY_ERR ly_ctx_unset_options(struct ly_ctx *ctx, uint16_t option
 LIBYANG_API_DECL uint16_t ly_ctx_get_change_count(const struct ly_ctx *ctx);
 
 /**
- * @brief Get the hash of all the modules in the context. Since order of the modules is significant,
- * even when 2 contexts have the same modules but loaded in a different order, the hash will differ.
+ * @brief Get the hash of all the modules in the context.
  *
  * Hash consists of all module names (1), their revisions (2), all enabled features (3), and their
- * imported/implemented state (4).
+ * imported/implemented state (4). Context module order is not significant.
  *
  * @param[in] ctx Context to be examined.
  * @return Context modules hash.
@@ -449,13 +481,15 @@ LIBYANG_API_DECL void ly_ctx_set_module_imp_clb(struct ly_ctx *ctx, ly_module_im
  * @brief Callback for getting arbitrary run-time data required by an extension instance.
  *
  * @param[in] ext Compiled extension instance.
+ * @param[in] parent Data parent node instance of a schema node with @p ext instance. In special cases
+ * (when not working with data) it can be NULL!
  * @param[in] user_data User-supplied callback data.
  * @param[out] ext_data Provided extension instance data.
  * @param[out] ext_data_free Whether the extension instance should free @p ext_data or not.
  * @return LY_ERR value.
  */
-typedef LY_ERR (*ly_ext_data_clb)(const struct lysc_ext_instance *ext, void *user_data, void **ext_data,
-        ly_bool *ext_data_free);
+typedef LY_ERR (*ly_ext_data_clb)(const struct lysc_ext_instance *ext, const struct lyd_node *parent, void *user_data,
+        void **ext_data, ly_bool *ext_data_free);
 
 /**
  * @brief Set callback providing run-time extension instance data. The expected data depend on the extension.
@@ -470,7 +504,7 @@ typedef LY_ERR (*ly_ext_data_clb)(const struct lysc_ext_instance *ext, void *use
  * @param[in] clb Callback responsible for returning the extension instance data.
  * @param[in] user_data Arbitrary data that will always be passed to the callback @p clb.
  */
-LIBYANG_API_DECL ly_ext_data_clb ly_ctx_set_ext_data_clb(struct ly_ctx *ctx, ly_ext_data_clb clb, void *user_data);
+LIBYANG_API_DECL ly_ext_data_clb ly_ctx_set_ext_data_clb(const struct ly_ctx *ctx, ly_ext_data_clb clb, void *user_data);
 
 /**
  * @brief Get YANG module of the given name and revision.
@@ -647,6 +681,53 @@ LIBYANG_API_DECL struct lys_module *ly_ctx_load_module(struct ly_ctx *ctx, const
 LIBYANG_API_DECL LY_ERR ly_ctx_get_yanglib_data(const struct ly_ctx *ctx, struct lyd_node **root,
         const char *content_id_format, ...);
 
+/**
+ * @brief Free all the parsed modules in a context. Any data manipulation will be possible but some schema functionality
+ * will no longer work.
+ *
+ * @param[in] ctx Context with parsed modules to free.
+ */
+LIBYANG_API_DECL void ly_ctx_free_parsed(struct ly_ctx *ctx);
+
+/**
+ * @brief Get the total size a compiled context requires for serialization.
+ *
+ * @param[in] ctx Context to use.
+ * @return Total required size;
+ * @return -1 on error.
+ */
+LIBYANG_API_DECL int ly_ctx_compiled_size(const struct ly_ctx *ctx);
+
+/**
+ * @brief Print (serialize) a compiled context (without any parsed modules) into a pre-allocated memory chunk.
+ *
+ * @param[in] ctx Compiled context to print.
+ * @param[in] mem Memory to print to, must be large enough.
+ * @param[out] mem_end Optional pointer after the printed context.
+ * @return LY_ERR value.
+ */
+LIBYANG_API_DECL LY_ERR ly_ctx_compiled_print(const struct ly_ctx *ctx, void *mem, void **mem_end);
+
+/**
+ * @brief Create a (immutable) context that was printed into a memory chunk.
+ *
+ * This function allows a given thread to create only one printed context at a particular memory address at any time.
+ * Another thread, however, may create a separate context at the same address.
+ *
+ * @param[in] mem Memory to use.
+ * @param[out] ctx Created immutable context.
+ * @return LY_ERR value.
+ */
+LIBYANG_API_DECL LY_ERR ly_ctx_new_printed(const void *mem, struct ly_ctx **ctx);
+
+/**
+ * @brief Check if the context was created from a printed (immutable) context.
+ *
+ * @param[in] ctx Context to check.
+ * @return 1 if the context was created from a printed context, 0 otherwise.
+ */
+LIBYANG_API_DECL ly_bool ly_ctx_is_printed(const struct ly_ctx *ctx);
+
 /**
  * @brief Free all internal structures of the specified context.
  *
