@@ -113,14 +113,6 @@ LY_ERR ly_vlog_build_data_path(const struct ly_ctx *ctx, char **path);
  */
 void ly_vlog(const struct ly_ctx *ctx, const char *apptag, LY_VECODE code, const char *format, ...) _FORMAT_PRINTF(4, 5);
 
-/**
- * @brief Move error items from source to target context replacing any previous ones.
- *
- * @param[in] src_ctx Source context to read errors from.
- * @param[in] trg_ctx Target context to set the errors for.
- */
-void ly_err_move(struct ly_ctx *src_ctx, struct ly_ctx *trg_ctx);
-
 /**
  * @brief Logger location data setter.
  *
@@ -335,37 +327,73 @@ int LY_VCODE_INSTREXP_len(const char *str);
  *****************************************************************************/
 
 /**
- * @brief Context error hash table record.
- */
-struct ly_ctx_err_rec {
-    struct ly_err_item *err;          /** pointer to the error items, if any */
-    pthread_t tid;                    /** pthread thread ID */
+  * @brief Private run-time context data.
+  *
+  * The data is thread and context address specific. It is used to store
+  * thread-specific data related to the context.
+  *
+  * No synchronization is needed for this data, it is only accessed by the thread that created it.
+  */
+struct ly_ctx_private_data {
+    const struct ly_ctx *ctx;       /**< context to which this data belongs */
+    pthread_t tid;                  /**< thread ID of the thread that created this context data */
+
+    struct ly_err_item *errs;       /**< thread-specific errors related to the context */
 };
 
+/**
+ * @brief Shared run-time context data.
+ *
+ * It is used to store data that can be shared between multiple threads
+ * using the same context address, e.g. printed contexts created from the same memory address.
+ *
+ * Members need to be protected by locks.
+ */
+struct ly_ctx_shared_data {
+    const struct ly_ctx *ctx;       /**< context to which this data belongs */
+    ATOMIC_T refcount;              /**< always 1 when using normal (not-printed) contexts (=> refcount does not have
+                                      * to be the same as the number of threads using the same context). Refcount gets
+                                      * incremented only when a new (next) printed context
+                                      * is created from the same memory address. */
+
+    struct ly_ht *pattern_ht;       /**< ht for storing patterns and their pcre2_codes.
+                                      * A pattern is used both as a key and a value to search for.
+                                      * This ht is only written to when the context is being compiled,
+                                      * afterwards, it is read-only. */
+
+    pthread_mutex_t ext_clb_lock;   /**< lock for accessing the extension callback */
+    ly_ext_data_clb ext_clb;        /**< optional callback for providing extension-specific run-time data for extensions */
+    void *ext_clb_data;             /**< optional private data for ext_clb */
+
+    struct ly_dict *data_dict;      /**< dictionary for data trees */
+
+    pthread_mutex_t leafref_links_lock; /**< lock for accessing the leafref links hash table */
+    struct ly_ht *leafref_links_ht;     /**< hash table of leafref links between term data nodes */
+};
+
+#define LY_CTX_INT_IMMUTABLE 0x80000000 /**< marks a context that was printed into a fixed-size memory block and
+                                             can even be shared between processes so it cannot be changed */
+
 /**
  * @brief Context of the YANG schemas
  */
 struct ly_ctx {
     struct ly_dict dict;              /**< dictionary to effectively store strings used in the context related structures */
     struct ly_set search_paths;       /**< set of directories where to search for schema's imports/includes */
-    struct ly_set list;               /**< set of loaded YANG schemas */
-    ly_module_imp_clb imp_clb;        /**< optional callback for retrieving missing included or imported modules */
+    struct ly_set modules;            /**< set of loaded YANG schemas */
+    ly_module_imp_clb imp_clb;        /**< optional callback for retrieving missing included or imported models */
     void *imp_clb_data;               /**< optional private data for ::ly_ctx.imp_clb */
     struct lys_glob_unres unres;      /**< global unres, should be empty unless there are modules prepared for
                                            compilation if ::LY_CTX_EXPLICIT_COMPILE flag is set */
-    uint16_t change_count;            /**< count of changes of the context, on some changes it could be incremented
+    uint32_t change_count;            /**< count of changes of the context, on some changes it could be incremented
                                            more times */
     uint32_t mod_hash;                /**< hash of the current context, includes name/revision/enabled features/implement state
                                            of every loaded module */
-    uint16_t flags;                   /**< context settings, see @ref contextoptions */
+    uint32_t opts;                    /**< context options, see @ref contextoptions */
 
-    ly_ext_data_clb ext_clb;          /**< optional callback for providing extension-specific run-time data for extensions */
-    void *ext_clb_data;               /**< optional private data for ::ly_ctx.ext_clb */
-    struct ly_ht *err_ht;             /**< hash table of thread-specific list of errors related to the context */
-    pthread_mutex_t lyb_hash_lock;    /**< lock for storing LYB schema hashes in schema nodes */
-    struct ly_ht *leafref_links_ht;   /**< hash table of leafref links between term data nodes */
     struct ly_set plugins_types;      /**< context specific set of type plugins */
     struct ly_set plugins_extensions; /**< contets specific set of extension plugins */
+    struct ly_ctx *parent_ctx;        /**< pointer to the parent context whose shared and private data to use, if set */
 };
 
 /**
@@ -375,6 +403,65 @@ struct ly_ctx {
  */
 void ly_ctx_new_change(struct ly_ctx *ctx);
 
+/**
+ * @brief Add a ctx data for a new context.
+ *
+ * Each context has its own thread-specific private data, see ::ly_ctx_private_data.
+ * Each context also has shared data, see ::ly_ctx_shared_data.
+ * Shared data can only be shared between printed contexts created from the same memory address.
+ *
+ * @param[in] ctx Newly created context.
+ * @return LY_SUCCESS on success, LY_EEXIST if a printed context created by the same thread and on the same memory address
+ * already exists, LY_EMEM on memory allocation failure.
+ */
+LY_ERR ly_ctx_data_add(const struct ly_ctx *ctx);
+
+/**
+ * @brief Remove a ctx data of a destroyed context.
+ *
+ * @param[in] ctx Destroyed context.
+ */
+void ly_ctx_data_del(const struct ly_ctx *ctx);
+
+/**
+ * @brief Get private (thread-specific) context data or create it if it does not exist.
+ *
+ * @param[in] ctx Context whose data to get.
+ * @return Context data of @p ctx, NULL on memory allocation failure.
+ */
+struct ly_ctx_private_data *ly_ctx_private_data_get_or_create(const struct ly_ctx *ctx);
+
+/**
+ * @brief Get shared (between the same contexts) context data.
+ *
+ * The contexts can be the same only if they are printed contexts created from the same memory address,
+ * although each of these contexts must be created by a different thread.
+ *
+ * @param[in] ctx Context whose shared data to get.
+ * @return Context shared data of @p ctx, NULL if not found.
+ */
+struct ly_ctx_shared_data *ly_ctx_shared_data_get(const struct ly_ctx *ctx);
+
+/**
+ * @brief Get context's data dictionary.
+ *
+ * @param[in] ctx Context whose data dictionary to get.
+ * @return Context's data dictionary, NULL if not found.
+ */
+struct ly_dict *ly_ctx_data_dict_get(const struct ly_ctx *ctx);
+
+/**
+ * @brief Hash table value-equal callback for comparing leafref links hash table record.
+ */
+ly_bool ly_ctx_ht_leafref_links_equal_cb(void *val1_p, void *val2_p, ly_bool mod, void *cb_data);
+
+/**
+ * @brief Callback for freeing leafref links recorcd internal resources.
+ *
+ * @param[in] val_p Pointer to leafref links record
+ */
+void ly_ctx_ht_leafref_links_rec_free(void *val_p);
+
 /**
  * @brief Get the (only) implemented YANG module specified by its name.
  *
@@ -386,28 +473,92 @@ void ly_ctx_new_change(struct ly_ctx *ctx);
  */
 struct lys_module *ly_ctx_get_module_implemented2(const struct ly_ctx *ctx, const char *name, size_t name_len);
 
+/**
+ * @brief Get a PCRE2 pattern code.
+ *
+ * If the pattern is not found in the context, it is compiled and cached.
+ *
+ * @param[in] ctx Context to get or create the pattern code in.
+ * @param[in] pattern Pattern string to search for or to compile and store.
+ * @param[out] pcode Optional compiled pattern code. DO NOT FREE IT, it is owned by the context.
+ * @return LY_ERR value.
+ */
+LY_ERR ly_ctx_shared_data_pattern_get(const struct ly_ctx *ctx, const char *pattern, const pcre2_code **pcode);
+
+/**
+ * @brief Free a PCRE2 pattern code, if found in the context cache.
+ *
+ * @param[in] ctx Context of the pattern.
+ * @param[in] pattern Pattern string to use.
+ */
+void ly_ctx_shared_data_pattern_del(const struct ly_ctx *ctx, const char *pattern);
+
+/******************************************************************************
+ * Dictionary
+ *****************************************************************************/
+
+/*
+ * The following lysdict_*() functions operate on the internal schema dictionary of the given context.
+ * They do NOT lock a mutex as opposed to the lydict_*() function family, because they do not operate on data.
+ * This is because there should be no concurrency when parsing modules into the given context.
+ */
+
+/**
+ * @brief Insert string into the internal schema dictionary of @p ctx. Use ::lydict_insert() to
+ * insert into the data dictionary.
+ *
+ * @param[in] ctx Context whose schema dictionary to store the string in.
+ * @param[in] value String to be stored in the dictionary.
+ * @param[in] len Number of bytes to store.
+ * @param[out] str_p Optional parameter to get pointer to the string corresponding to the @p value and stored in dictionary.
+ * @return LY_SUCCESS in case of successful insertion into dictionary, note that the function does not return LY_EEXIST.
+ * @return LY_EMEM in case of memory allocation failure.
+ */
+LY_ERR lysdict_insert(const struct ly_ctx *ctx, const char *value, size_t len, const char **str_p);
+
+/**
+ * @brief Insert string into the internal schema dictionary of @p ctx - zerocopy version.
+ * Use ::lydict_insert_zc() to insert into the data dictionary.
+ *
+ * @param[in] ctx Context whose schema dictionary to store the string in.
+ * @param[in] value String to be stored in the dictionary.
+ * @param[in] len Number of bytes to store.
+ * @param[out] str_p Optional parameter to get pointer to the string corresponding to the @p value and stored in dictionary.
+ * @return LY_SUCCESS in case of successful insertion into dictionary, note that the function does not return LY_EEXIST.
+ * @return LY_EMEM in case of memory allocation failure.
+ */
+LY_ERR lysdict_insert_zc(const struct ly_ctx *ctx, char *value, const char **str_p);
+
+/**
+ * @brief Remove specified string from the internal schema dictionary of @p ctx. It decrements reference
+ * counter for the string and if it is zero, the string itself is freed.
+ *
+ * @param[in] ctx libyang context handler
+ * @param[in] value String to be freed. Note, that not only the string itself
+ * must match the stored value, but also the address is being compared and the
+ * counter is decremented only if it matches. If NULL, function does nothing.
+ * @return LY_SUCCESS if the value was found and removed (or refcount decreased).
+ * @return LY_ENOTFOUND if the value was not found.
+ * @return LY_ERR on other errors.
+ */
+LY_ERR lysdict_remove(const struct ly_ctx *ctx, const char *value);
+
+/**
+ * @brief Duplicate a string in the internal schema dictionary of @p ctx. Only a reference counter is incremented.
+ *
+ * @param[in] ctx Context whose schema dictionary to duplicate the string in.
+ * @param[in] value NULL-terminated string to be duplicated in the dictionary (reference counter is incremented).
+ * @param[out] str_p Optional parameter to get pointer to the string corresponding to the @p value and stored in dictionary.
+ * @return LY_SUCCESS in case the string already exists in the dictionary.
+ * @return LY_ENOTFOUND in case the string was not found.
+ * @return LY_ERR on other errors
+ */
+LY_ERR lysdict_dup(const struct ly_ctx *ctx, const char *value, const char **str_p);
+
 /******************************************************************************
  * Generic useful functions.
  *****************************************************************************/
 
-/**
- * @brief Insert string into dictionary.
- *
- * @param[in] CTX libyang context.
- * @param[in] STRING string to store.
- * @param[in] LEN length of the string in WORD to store.
- * @param[in,out] DYNAMIC Set to 1 if @p STRING is dynamically allocated, 0 otherwise.
- * If set to 1, zerocopy version of lydict_insert is used.
- * @param[out] TARGET pointer is set to @p STRING value stored in the dictionary.
- */
-#define INSERT_STRING_RET(CTX, STRING, LEN, DYNAMIC, TARGET) \
-    if (DYNAMIC) { \
-        LY_CHECK_RET(lydict_insert_zc(CTX, (char *)(STRING), &(TARGET))); \
-    } else { \
-        LY_CHECK_RET(lydict_insert(CTX, LEN ? (STRING) : "", LEN, &(TARGET))); \
-    } \
-    DYNAMIC = 0
-
 /**
  * @brief Wrapper for realloc() call. The only difference is that if it fails to
  * allocate the requested memory, the original memory is freed as well.
@@ -537,7 +688,7 @@ LY_ERR ly_value_prefix_next(const char *str_begin, const char *str_end, uint32_t
  * @param[out] bytes_read Number of bytes used to encode the read utf8_char.
  * @return LY_ERR value
  */
-LY_ERR ly_getutf8(const char **input, uint32_t *utf8_char, size_t *bytes_read);
+LY_ERR ly_getutf8(const char **input, uint32_t *utf8_char, uint32_t *bytes_read);
 
 /**
  * @brief Check an UTF-8 character is valid.
@@ -548,7 +699,7 @@ LY_ERR ly_getutf8(const char **input, uint32_t *utf8_char, size_t *bytes_read);
  * @return LY_SUCCESS on success
  * @return LY_EINVAL in case of invalid UTF-8 character.
  */
-LY_ERR ly_checkutf8(const char *input, size_t in_len, size_t *utf8_len);
+LY_ERR ly_checkutf8(const char *input, uint32_t in_len, uint32_t *utf8_len);
 
 /**
  * @brief Store UTF-8 character specified as 4byte integer into the dst buffer.
@@ -567,7 +718,7 @@ LY_ERR ly_checkutf8(const char *input, size_t in_len, size_t *utf8_len);
  * @return LY_SUCCESS on success
  * @return LY_EINVAL in case of invalid UTF-8 @p value to store.
  */
-LY_ERR ly_pututf8(char *dst, uint32_t value, size_t *bytes_written);
+LY_ERR ly_pututf8(char *dst, uint32_t value, uint32_t *bytes_written);
 
 /**
  * @brief Get number of characters in the @p str, taking multibyte characters into account.
@@ -578,7 +729,7 @@ LY_ERR ly_pututf8(char *dst, uint32_t value, size_t *bytes_written);
  * string, strlen() can be used.
  * @return Number of characters in (possibly) multibyte characters string.
  */
-size_t ly_utf8len(const char *str, size_t bytes);
+uint32_t ly_utf8len(const char *str, uint32_t bytes);
 
 /**
  * @brief Parse signed integer with possible limitation.
@@ -597,7 +748,7 @@ size_t ly_utf8len(const char *str, size_t bytes);
  * LY_EVALID - string contains invalid value,
  * LY_SUCCESS - successful parsing.
  */
-LY_ERR ly_parse_int(const char *val_str, size_t val_len, int64_t min, int64_t max, int base, int64_t *ret);
+LY_ERR ly_parse_int(const char *val_str, uint32_t val_len, int64_t min, int64_t max, int base, int64_t *ret);
 
 /**
  * @brief Parse unsigned integer with possible limitation.
@@ -615,7 +766,7 @@ LY_ERR ly_parse_int(const char *val_str, size_t val_len, int64_t min, int64_t ma
  * LY_EVALID - string contains invalid value,
  * LY_SUCCESS - successful parsing.
  */
-LY_ERR ly_parse_uint(const char *val_str, size_t val_len, uint64_t max, int base, uint64_t *ret);
+LY_ERR ly_parse_uint(const char *val_str, uint32_t val_len, uint64_t max, int base, uint64_t *ret);
 
 /**
  * @brief Parse a node-identifier.
@@ -629,7 +780,7 @@ LY_ERR ly_parse_uint(const char *val_str, size_t val_len, uint64_t max, int base
  * @param[out] name_len Length of the node's name.
  * @return LY_ERR value: LY_SUCCESS or LY_EINVAL in case of invalid character in the id.
  */
-LY_ERR ly_parse_nodeid(const char **id, const char **prefix, size_t *prefix_len, const char **name, size_t *name_len);
+LY_ERR ly_parse_nodeid(const char **id, const char **prefix, uint32_t *prefix_len, const char **name, uint32_t *name_len);
 
 /**
  * @brief parse instance-identifier's predicate, supports key-predicate, leaf-list-predicate and pos rules from YANG ABNF Grammar.
@@ -650,9 +801,9 @@ LY_ERR ly_parse_nodeid(const char **id, const char **prefix, size_t *prefix_len,
  * @return LY_EVALID in case of invalid predicate form.
  * @return LY_EINVAL in case of reaching @p limit when parsing @p pred.
  */
-LY_ERR ly_parse_instance_predicate(const char **pred, size_t limit, LYD_FORMAT format,
-        const char **prefix, size_t *prefix_len, const char **id, size_t *id_len,
-        const char **value, size_t *value_len, const char **errmsg);
+LY_ERR ly_parse_instance_predicate(const char **pred, uint32_t limit, LYD_FORMAT format,
+        const char **prefix, uint32_t *prefix_len, const char **id, uint32_t *id_len,
+        const char **value, uint32_t *value_len, const char **errmsg);
 
 /**
  * @brief mmap(2) wrapper to map input files into memory to unify parsing.
@@ -690,9 +841,11 @@ LY_ERR ly_strcat(char **dest, const char *format, ...) _FORMAT_PRINTF(2, 3);
  * @brief Get schema (context) for a mount point.
  *
  * @param[in] ext Compiled extension instance where the context is also stored.
+ * @param[in] parent Data parent node instance of a schema node with @p ext instance. In special cases
+ * (when not working with data) it can be NULL!
  * @param[out] ext_ctx Schema to use for parsing the data.
  * @return LY_ERR value.
  */
-LY_ERR lyplg_ext_schema_mount_get_ctx(struct lysc_ext_instance *ext, const struct ly_ctx **ext_ctx);
+LY_ERR lyplg_ext_schema_mount_get_ctx(struct lysc_ext_instance *ext, const struct lyd_node *parent, const struct ly_ctx **ext_ctx);
 
 #endif /* LY_COMMON_H_ */
