@@ -1,9 +1,10 @@
 /**
  * @file enumeration.c
  * @author Radek Krejci <rkrejci@cesnet.cz>
+ * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief Built-in enumeration type plugin.
  *
- * Copyright (c) 2019-2021 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -33,19 +34,45 @@
  *
  * | Size (B) | Mandatory | Type | Meaning |
  * | :------  | :-------: | :--: | :-----: |
- * | 4        | yes | `int32 *` | assigned little-endian value of the enum |
+ * | fixed for a specific type | yes | `int32 *` | assigned little-endian value of the enum |
  */
 
-LIBYANG_API_DEF LY_ERR
-lyplg_type_store_enum(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, size_t value_len,
+#define ENUM_FIXED_SIZE_BITS(type) \
+        lyplg_type_get_highest_set_bit_pos(\
+        ((struct lysc_type_enum *)type)->enums[LY_ARRAY_COUNT(((struct lysc_type_enum *)type)->enums) - 1].value)
+
+static void
+lyplg_type_lyb_size_enum(const struct lysc_type *type, enum lyplg_lyb_size_type *size_type, uint32_t *fixed_size_bits)
+{
+    const struct lysc_type_enum *type_enum = (struct lysc_type_enum *)type;
+    uint32_t max_value;
+
+    *size_type = LYPLG_LYB_SIZE_FIXED_BITS;
+
+    if (type_enum->enums[0].value < 0) {
+        /* we need the full 4 bytes */
+        *fixed_size_bits = 32;
+        return;
+    }
+
+    /* value of the last enum, sorted */
+    max_value = type_enum->enums[LY_ARRAY_COUNT(type_enum->enums) - 1].value;
+
+    /* learn the position of the highest set bit, the least amount of bits that can hold the number */
+    *fixed_size_bits = lyplg_type_get_highest_set_bit_pos(max_value);
+}
+
+static LY_ERR
+lyplg_type_store_enum(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, uint32_t value_size_bits,
         uint32_t options, LY_VALUE_FORMAT format, void *UNUSED(prefix_data), uint32_t hints,
-        const struct lysc_node *UNUSED(ctx_node), struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres),
-        struct ly_err_item **err)
+        const struct lysc_node *UNUSED(ctx_node), const struct lysc_ext_instance *UNUSED(top_ext),
+        struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres), struct ly_err_item **err)
 {
     struct lysc_type_enum *type_enum = (struct lysc_type_enum *)type;
     LY_ERR ret = LY_SUCCESS;
     LY_ARRAY_COUNT_TYPE u;
     ly_bool found = 0;
+    uint32_t value_size;
     int64_t num = 0;
     int32_t num_val;
 
@@ -53,16 +80,14 @@ lyplg_type_store_enum(const struct ly_ctx *ctx, const struct lysc_type *type, co
     memset(storage, 0, sizeof *storage);
     storage->realtype = type;
 
-    if (format == LY_VALUE_LYB) {
-        /* validation */
-        if (value_len != 4) {
-            ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid LYB enumeration value size %zu (expected 4).",
-                    value_len);
-            goto cleanup;
-        }
+    /* check value length */
+    ret = lyplg_type_check_value_size("enumeration", format, value_size_bits, LYPLG_LYB_SIZE_FIXED_BITS,
+            ENUM_FIXED_SIZE_BITS(type), &value_size, err);
+    LY_CHECK_GOTO(ret, cleanup);
 
+    if (format == LY_VALUE_LYB) {
         /* convert the value to host byte order */
-        memcpy(&num, value, value_len);
+        memcpy(&num, value, value_size);
         num = le64toh(num);
         num_val = num;
 
@@ -92,12 +117,12 @@ lyplg_type_store_enum(const struct ly_ctx *ctx, const struct lysc_type *type, co
     }
 
     /* check hints */
-    ret = lyplg_type_check_hints(hints, value, value_len, type->basetype, NULL, err);
+    ret = lyplg_type_check_hints(hints, value, value_size, type->basetype, NULL, err);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* find the matching enumeration value item */
     LY_ARRAY_FOR(type_enum->enums, u) {
-        if (!ly_strncmp(type_enum->enums[u].name, value, value_len)) {
+        if (!ly_strncmp(type_enum->enums[u].name, value, value_size)) {
             found = 1;
             break;
         }
@@ -105,7 +130,7 @@ lyplg_type_store_enum(const struct ly_ctx *ctx, const struct lysc_type *type, co
 
     if (!found) {
         /* enum not found */
-        ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid enumeration value \"%.*s\".", (int)value_len,
+        ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid enumeration value \"%.*s\".", (int)value_size,
                 (char *)value);
         goto cleanup;
     }
@@ -119,7 +144,7 @@ lyplg_type_store_enum(const struct ly_ctx *ctx, const struct lysc_type *type, co
         options &= ~LYPLG_TYPE_STORE_DYNAMIC;
         LY_CHECK_GOTO(ret, cleanup);
     } else {
-        ret = lydict_insert(ctx, value, value_len, &storage->_canonical);
+        ret = lydict_insert(ctx, value, value_size, &storage->_canonical);
         LY_CHECK_GOTO(ret, cleanup);
     }
 
@@ -134,22 +159,22 @@ cleanup:
     return ret;
 }
 
-LIBYANG_API_DEF int
+static int
 lyplg_type_sort_enum(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *val1,
         const struct lyd_value *val2)
 {
-    if (val1->enum_item->value > val2->enum_item->value) {
+    if (val1->enum_item->value < val2->enum_item->value) {
         return -1;
-    } else if (val1->enum_item->value < val2->enum_item->value) {
+    } else if (val1->enum_item->value > val2->enum_item->value) {
         return 1;
     } else {
         return 0;
     }
 }
 
-LIBYANG_API_DEF const void *
+static const void *
 lyplg_type_print_enum(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *value, LY_VALUE_FORMAT format,
-        void *UNUSED(prefix_data), ly_bool *dynamic, size_t *value_len)
+        void *UNUSED(prefix_data), ly_bool *dynamic, uint32_t *value_size_bits)
 {
     int64_t prev_num = 0, num = 0;
     void *buf;
@@ -160,8 +185,8 @@ lyplg_type_print_enum(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *
         if (num == prev_num) {
             /* values are equal, little-endian */
             *dynamic = 0;
-            if (value_len) {
-                *value_len = 4;
+            if (value_size_bits) {
+                *value_size_bits = ENUM_FIXED_SIZE_BITS(value->realtype);
             }
             return &value->enum_item->value;
         } else {
@@ -170,8 +195,8 @@ lyplg_type_print_enum(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *
             LY_CHECK_RET(!buf, NULL);
 
             *dynamic = 1;
-            if (value_len) {
-                *value_len = 4;
+            if (value_size_bits) {
+                *value_size_bits = ENUM_FIXED_SIZE_BITS(value->realtype);
             }
             memcpy(buf, &num, 4);
             return buf;
@@ -182,8 +207,8 @@ lyplg_type_print_enum(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *
     if (dynamic) {
         *dynamic = 0;
     }
-    if (value_len) {
-        *value_len = strlen(value->_canonical);
+    if (value_size_bits) {
+        *value_size_bits = strlen(value->_canonical) * 8;
     }
     return value->_canonical;
 }
@@ -201,15 +226,16 @@ const struct lyplg_type_record plugins_enumeration[] = {
         .revision = NULL,
         .name = LY_TYPE_ENUM_STR,
 
-        .plugin.id = "libyang 2 - enumeration, version 1",
+        .plugin.id = "ly2 enumeration",
+        .plugin.lyb_size = lyplg_type_lyb_size_enum,
         .plugin.store = lyplg_type_store_enum,
-        .plugin.validate = NULL,
+        .plugin.validate_value = NULL,
+        .plugin.validate_tree = NULL,
         .plugin.compare = lyplg_type_compare_simple,
         .plugin.sort = lyplg_type_sort_enum,
         .plugin.print = lyplg_type_print_enum,
         .plugin.duplicate = lyplg_type_dup_simple,
         .plugin.free = lyplg_type_free_simple,
-        .plugin.lyb_data_len = 4,
     },
     {0}
 };
