@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief ietf-inet-types ipv6-address type plugin.
  *
- * Copyright (c) 2019-2021 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -43,9 +43,9 @@
  * @page howtoDataLYB LYB Binary Format
  * @subsection howtoDataLYBTypesIPv6Address ipv6-address (ietf-inet-types)
  *
- * | Size (B) | Mandatory | Type | Meaning |
+ * | Size (b) | Mandatory | Type | Meaning |
  * | :------  | :-------: | :--: | :-----: |
- * | 16       | yes       | `struct in6_addr *` | IPv6 address in network-byte order |
+ * | 128      | yes       | `struct in6_addr *` | IPv6 address in network-byte order |
  * | string length | no        | `char *` | IPv6 address zone string |
  */
 
@@ -64,13 +64,13 @@ static void lyplg_type_free_ipv6_address(const struct ly_ctx *ctx, struct lyd_va
  * @return LY_ERR value.
  */
 static LY_ERR
-ipv6address_str2ip(const char *value, size_t value_len, uint32_t options, const struct ly_ctx *ctx,
+ipv6address_str2ip(const char *value, uint32_t value_len, uint32_t options, const struct ly_ctx *ctx,
         struct in6_addr *addr, const char **zone, struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     const char *addr_no_zone;
     char *zone_ptr = NULL, *addr_dyn = NULL;
-    size_t zone_len;
+    uint32_t zone_len;
 
     /* store zone and get the string IPv6 address without it */
     if ((zone_ptr = ly_strnchr(value, '%', value_len))) {
@@ -103,7 +103,7 @@ ipv6address_str2ip(const char *value, size_t value_len, uint32_t options, const
 
     /* store the IPv6 address in network-byte order */
     if (!inet_pton(AF_INET6, addr_no_zone, addr)) {
-        ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Failed to convert IPv6 address \"%s\".", addr_no_zone);
+        ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Failed to store IPv6 address \"%s\".", addr_no_zone);
         goto cleanup;
     }
 
@@ -121,16 +121,15 @@ cleanup:
  * @brief Implementation of ::lyplg_type_store_clb for the ipv6-address ietf-inet-types type.
  */
 static LY_ERR
-lyplg_type_store_ipv6_address(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, size_t value_len,
+lyplg_type_store_ipv6_address(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, uint32_t value_size_bits,
         uint32_t options, LY_VALUE_FORMAT format, void *UNUSED(prefix_data), uint32_t hints,
-        const struct lysc_node *UNUSED(ctx_node), struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres),
-        struct ly_err_item **err)
+        const struct lysc_node *UNUSED(ctx_node), const struct lysc_ext_instance *UNUSED(top_ext),
+        struct lyd_value *storage, struct lys_glob_unres *UNUSED(unres), struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
-    const char *value_str = value;
-    struct lysc_type_str *type_str = (struct lysc_type_str *)type;
     struct lyd_value_ipv6_address *val;
-    size_t i;
+    const char *value_str = value;
+    uint32_t value_size, i;
 
     /* init storage */
     memset(storage, 0, sizeof *storage);
@@ -138,14 +137,16 @@ lyplg_type_store_ipv6_address(const struct ly_ctx *ctx, const struct lysc_type *
     LY_CHECK_ERR_GOTO(!val, ret = LY_EMEM, cleanup);
     storage->realtype = type;
 
+    value_size = LYPLG_BITS2BYTES(value_size_bits);
+
     if (format == LY_VALUE_LYB) {
         /* validation */
-        if (value_len < 16) {
-            ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid LYB ipv6-address value size %zu "
-                    "(expected at least 16).", value_len);
+        if (value_size_bits < 128) {
+            ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid LYB ipv6-address value size %" PRIu32
+                    " b (expected at least 128 b).", value_size_bits);
             goto cleanup;
         }
-        for (i = 16; i < value_len; ++i) {
+        for (i = 16; i < value_size; ++i) {
             if (!isalnum(value_str[i])) {
                 ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL, "Invalid LYB ipv6-address zone character 0x%x.",
                         value_str[i]);
@@ -157,8 +158,8 @@ lyplg_type_store_ipv6_address(const struct ly_ctx *ctx, const struct lysc_type *
         memcpy(&val->addr, value, sizeof val->addr);
 
         /* store zone, if any */
-        if (value_len > 16) {
-            ret = lydict_insert(ctx, value_str + 16, value_len - 16, &val->zone);
+        if (value_size > 16) {
+            ret = lydict_insert(ctx, value_str + 16, value_size - 16, &val->zone);
             LY_CHECK_GOTO(ret, cleanup);
         } else {
             val->zone = NULL;
@@ -169,22 +170,11 @@ lyplg_type_store_ipv6_address(const struct ly_ctx *ctx, const struct lysc_type *
     }
 
     /* check hints */
-    ret = lyplg_type_check_hints(hints, value, value_len, type->basetype, NULL, err);
-    LY_CHECK_GOTO(ret, cleanup);
-
-    /* length restriction of the string */
-    if (type_str->length) {
-        /* value_len is in bytes, but we need number of characters here */
-        ret = lyplg_type_validate_range(LY_TYPE_STRING, type_str->length, ly_utf8len(value, value_len), value, value_len, err);
-        LY_CHECK_GOTO(ret, cleanup);
-    }
-
-    /* pattern restrictions */
-    ret = lyplg_type_validate_patterns(type_str->patterns, value, value_len, err);
+    ret = lyplg_type_check_hints(hints, value, value_size, type->basetype, NULL, err);
     LY_CHECK_GOTO(ret, cleanup);
 
     /* get the network-byte order address */
-    ret = ipv6address_str2ip(value, value_len, options, ctx, &val->addr, &val->zone, err);
+    ret = ipv6address_str2ip(value, value_size, options, ctx, &val->addr, &val->zone, err);
     LY_CHECK_GOTO(ret, cleanup);
 
     if (format == LY_VALUE_CANON) {
@@ -194,7 +184,7 @@ lyplg_type_store_ipv6_address(const struct ly_ctx *ctx, const struct lysc_type *
             options &= ~LYPLG_TYPE_STORE_DYNAMIC;
             LY_CHECK_GOTO(ret, cleanup);
         } else {
-            ret = lydict_insert(ctx, value_len ? value : "", value_len, &storage->_canonical);
+            ret = lydict_insert(ctx, value_size ? value : "", value_size, &storage->_canonical);
             LY_CHECK_GOTO(ret, cleanup);
         }
     }
@@ -263,10 +253,10 @@ lyplg_type_sort_ipv6_address(const struct ly_ctx *UNUSED(ctx), const struct lyd_
  */
 static const void *
 lyplg_type_print_ipv6_address(const struct ly_ctx *ctx, const struct lyd_value *value, LY_VALUE_FORMAT format,
-        void *UNUSED(prefix_data), ly_bool *dynamic, size_t *value_len)
+        void *UNUSED(prefix_data), ly_bool *dynamic, uint32_t *value_size_bits)
 {
     struct lyd_value_ipv6_address *val;
-    size_t zone_len;
+    uint32_t zone_len;
     char *ret;
 
     LYD_VALUE_GET(value, val);
@@ -275,8 +265,8 @@ lyplg_type_print_ipv6_address(const struct ly_ctx *ctx, const struct lyd_value *
         if (!val->zone) {
             /* address-only, const */
             *dynamic = 0;
-            if (value_len) {
-                *value_len = sizeof val->addr;
+            if (value_size_bits) {
+                *value_size_bits = sizeof val->addr * 8;
             }
             return &val->addr;
         }
@@ -290,8 +280,8 @@ lyplg_type_print_ipv6_address(const struct ly_ctx *ctx, const struct lyd_value *
         memcpy(ret + sizeof val->addr, val->zone, zone_len);
 
         *dynamic = 1;
-        if (value_len) {
-            *value_len = sizeof val->addr + zone_len;
+        if (value_size_bits) {
+            *value_size_bits = sizeof val->addr * 8 + zone_len * 8;
         }
         return ret;
     }
@@ -326,8 +316,8 @@ lyplg_type_print_ipv6_address(const struct ly_ctx *ctx, const struct lyd_value *
     if (dynamic) {
         *dynamic = 0;
     }
-    if (value_len) {
-        *value_len = strlen(value->_canonical);
+    if (value_size_bits) {
+        *value_size_bits = strlen(value->_canonical) * 8;
     }
     return value->_canonical;
 }
@@ -392,15 +382,16 @@ const struct lyplg_type_record plugins_ipv6_address[] = {
         .revision = "2013-07-15",
         .name = "ipv6-address",
 
-        .plugin.id = "libyang 2 - ipv6-address, version 1",
+        .plugin.id = "ly2 ipv6-address",
+        .plugin.lyb_size = lyplg_type_lyb_size_variable_bytes,
         .plugin.store = lyplg_type_store_ipv6_address,
-        .plugin.validate = NULL,
+        .plugin.validate_value = NULL,
+        .plugin.validate_tree = NULL,
         .plugin.compare = lyplg_type_compare_ipv6_address,
         .plugin.sort = lyplg_type_sort_ipv6_address,
         .plugin.print = lyplg_type_print_ipv6_address,
         .plugin.duplicate = lyplg_type_dup_ipv6_address,
         .plugin.free = lyplg_type_free_ipv6_address,
-        .plugin.lyb_data_len = -1,
     },
     {0}
 };
