@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief ietf-netconf-acm node-instance-identifier type plugin.
  *
- * Copyright (c) 2019-2021 CESNET, z.s.p.o.
+ * Copyright (c) 2019 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -30,9 +30,9 @@
  * @page howtoDataLYB LYB Binary Format
  * @subsection howtoDataLYBTypesNodeInstanceIdentifier node-instance-identifier (ietf-netconf-acm)
  *
- * | Size (B) | Mandatory | Type | Meaning |
+ * | Size (b) | Mandatory | Type | Meaning |
  * | :------  | :-------: | :--: | :-----: |
- * | string length | yes | `char *` | string JSON format of the instance-identifier |
+ * | variable, full bytes | yes | `char *` | string JSON format of the instance-identifier |
  */
 
 /**
@@ -52,7 +52,7 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
     char *result = NULL, quot;
     const struct lys_module *mod = NULL, *local_mod = NULL;
     struct ly_set *mods;
-    ly_bool inherit_prefix = 0, d;
+    ly_bool inherit_prefix = 0;
     const char *strval;
 
     if (!path) {
@@ -104,8 +104,8 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
                 break;
             case LY_PATH_PREDTYPE_LIST:
                 /* key-predicate */
-                strval = pred->value.realtype->plugin->print(path[u].node->module->ctx, &pred->value, format, prefix_data,
-                        &d, NULL);
+                ret = lyplg_type_print_val(pred->key, pred->value, format, prefix_data, &strval);
+                LY_CHECK_GOTO(ret, cleanup);
 
                 /* default quote */
                 quot = '\'';
@@ -119,14 +119,12 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
                     ret = ly_strcat(&result, "[%s:%s=%c%s%c]", lyplg_type_get_prefix(pred->key->module, format, prefix_data),
                             pred->key->name, quot, strval, quot);
                 }
-                if (d) {
-                    free((char *)strval);
-                }
+                lydict_remove(pred->key->module->ctx, strval);
                 break;
             case LY_PATH_PREDTYPE_LEAFLIST:
                 /* leaf-list-predicate */
-                strval = pred->value.realtype->plugin->print(path[u].node->module->ctx, &pred->value, format, prefix_data,
-                        &d, NULL);
+                ret = lyplg_type_print_val(path[u].node, pred->value, format, prefix_data, &strval);
+                LY_CHECK_GOTO(ret, cleanup);
 
                 /* default quote */
                 quot = '\'';
@@ -134,9 +132,7 @@ node_instanceid_path2str(const struct ly_path *path, LY_VALUE_FORMAT format, voi
                     quot = '"';
                 }
                 ret = ly_strcat(&result, "[.=%c%s%c]", quot, strval, quot);
-                if (d) {
-                    free((char *)strval);
-                }
+                lydict_remove(path[u].node->module->ctx, strval);
                 break;
             case LY_PATH_PREDTYPE_LIST_VAR:
                 /* key-predicate with a variable */
@@ -170,13 +166,14 @@ cleanup:
  * @brief Implementation of ::lyplg_type_store_clb for the node-instance-identifier ietf-netconf-acm type.
  */
 static LY_ERR
-lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, size_t value_len,
+lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_type *type, const void *value, uint32_t value_size_bits,
         uint32_t options, LY_VALUE_FORMAT format, void *prefix_data, uint32_t hints, const struct lysc_node *ctx_node,
-        struct lyd_value *storage, struct lys_glob_unres *unres, struct ly_err_item **err)
+        const struct lysc_ext_instance *top_ext, struct lyd_value *storage, struct lys_glob_unres *unres,
+        struct ly_err_item **err)
 {
     LY_ERR ret = LY_SUCCESS;
     struct lyxp_expr *exp = NULL;
-    uint32_t prefix_opt = 0;
+    uint32_t value_size, prefix_opt = 0;
     struct ly_path *path = NULL;
     char *canon;
 
@@ -184,11 +181,16 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
     memset(storage, 0, sizeof *storage);
     storage->realtype = type;
 
-    /* check hints */
-    ret = lyplg_type_check_hints(hints, value, value_len, type->basetype, NULL, err);
+    /* check value length */
+    ret = lyplg_type_check_value_size("node-instance-identifier", format, value_size_bits, LYPLG_LYB_SIZE_VARIABLE_BYTES,
+            0, &value_size, err);
     LY_CHECK_GOTO(ret, cleanup);
 
-    if ((((char *)value)[0] == '/') && (value_len == 1)) {
+    /* check hints */
+    ret = lyplg_type_check_hints(hints, value, value_size, type->basetype, NULL, err);
+    LY_CHECK_GOTO(ret, cleanup);
+
+    if ((((char *)value)[0] == '/') && (value_size == 1)) {
         /* special path */
         format = LY_VALUE_CANON;
         goto store;
@@ -209,10 +211,10 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
     }
 
     /* parse the value */
-    ret = ly_path_parse(ctx, ctx_node, value, value_len, 0, LY_PATH_BEGIN_ABSOLUTE, prefix_opt, LY_PATH_PRED_SIMPLE, &exp);
+    ret = ly_path_parse(ctx, ctx_node, value, value_size, 0, LY_PATH_BEGIN_ABSOLUTE, prefix_opt, LY_PATH_PRED_SIMPLE, &exp);
     if (ret) {
         ret = ly_err_new(err, LY_EVALID, LYVE_DATA, NULL, NULL,
-                "Invalid node-instance-identifier \"%.*s\" value - syntax error.", (int)value_len, (char *)value);
+                "Invalid node-instance-identifier \"%.*s\" value - syntax error.", (int)value_size, (char *)value);
         goto cleanup;
     }
 
@@ -223,12 +225,12 @@ lyplg_type_store_node_instanceid(const struct ly_ctx *ctx, const struct lysc_typ
 
     /* resolve it on schema tree, use JSON format instead of LYB because for this type they are equal but for some
      * nested types (such as numbers in predicates in the path) LYB would be invalid */
-    ret = ly_path_compile(ctx, NULL, ctx_node, NULL, exp, (ctx_node && (ctx_node->flags & LYS_IS_OUTPUT)) ?
+    ret = ly_path_compile(ctx, NULL, ctx_node, top_ext, exp, (ctx_node && (ctx_node->flags & LYS_IS_OUTPUT)) ?
             LY_PATH_OPER_OUTPUT : LY_PATH_OPER_INPUT, LY_PATH_TARGET_MANY, 1, (format == LY_VALUE_LYB) ?
             LY_VALUE_JSON : format, prefix_data, &path);
     if (ret) {
         ret = ly_err_new(err, ret, LYVE_DATA, NULL, NULL,
-                "Invalid node-instance-identifier \"%.*s\" value - semantic error.", (int)value_len, (char *)value);
+                "Invalid node-instance-identifier \"%.*s\" value - semantic error.", (int)value_size, (char *)value);
         goto cleanup;
     }
 
@@ -243,7 +245,7 @@ store:
             options &= ~LYPLG_TYPE_STORE_DYNAMIC;
             LY_CHECK_GOTO(ret, cleanup);
         } else {
-            ret = lydict_insert(ctx, value, value_len, &storage->_canonical);
+            ret = lydict_insert(ctx, value, value_size, &storage->_canonical);
             LY_CHECK_GOTO(ret, cleanup);
         }
     } else {
@@ -256,7 +258,7 @@ store:
     }
 
 cleanup:
-    lyxp_expr_free(ctx, exp);
+    lyxp_expr_free(exp);
     if (options & LYPLG_TYPE_STORE_DYNAMIC) {
         free((void *)value);
     }
@@ -272,7 +274,7 @@ cleanup:
  */
 static const void *
 lyplg_type_print_node_instanceid(const struct ly_ctx *UNUSED(ctx), const struct lyd_value *value, LY_VALUE_FORMAT format,
-        void *prefix_data, ly_bool *dynamic, size_t *value_len)
+        void *prefix_data, ly_bool *dynamic, uint32_t *value_size_bits)
 {
     char *ret;
 
@@ -280,8 +282,8 @@ lyplg_type_print_node_instanceid(const struct ly_ctx *UNUSED(ctx), const struct
         if (dynamic) {
             *dynamic = 0;
         }
-        if (value_len) {
-            *value_len = strlen(value->_canonical);
+        if (value_size_bits) {
+            *value_size_bits = strlen(value->_canonical) * 8;
         }
         return value->_canonical;
     }
@@ -291,8 +293,8 @@ lyplg_type_print_node_instanceid(const struct ly_ctx *UNUSED(ctx), const struct
         return NULL;
     }
     *dynamic = 1;
-    if (value_len) {
-        *value_len = strlen(ret);
+    if (value_size_bits) {
+        *value_size_bits = strlen(ret) * 8;
     }
     return ret;
 }
@@ -338,30 +340,32 @@ const struct lyplg_type_record plugins_node_instanceid[] = {
         .revision = "2012-02-22",
         .name = "node-instance-identifier",
 
-        .plugin.id = "libyang 2 - node-instance-identifier, version 1",
+        .plugin.id = "ly2 node-instance-identifier",
+        .plugin.lyb_size = lyplg_type_lyb_size_variable_bytes,
         .plugin.store = lyplg_type_store_node_instanceid,
-        .plugin.validate = NULL,
+        .plugin.validate_value = NULL,
+        .plugin.validate_tree = NULL,
         .plugin.compare = lyplg_type_compare_simple,
         .plugin.sort = lyplg_type_sort_simple,
         .plugin.print = lyplg_type_print_node_instanceid,
         .plugin.duplicate = lyplg_type_dup_node_instanceid,
         .plugin.free = lyplg_type_free_instanceid,
-        .plugin.lyb_data_len = -1,
     },
     {
         .module = "ietf-netconf-acm",
         .revision = "2018-02-14",
         .name = "node-instance-identifier",
 
-        .plugin.id = "libyang 2 - node-instance-identifier, version 1",
+        .plugin.id = "ly2 node-instance-identifier",
+        .plugin.lyb_size = lyplg_type_lyb_size_variable_bytes,
         .plugin.store = lyplg_type_store_node_instanceid,
-        .plugin.validate = NULL,
+        .plugin.validate_value = NULL,
+        .plugin.validate_tree = NULL,
         .plugin.compare = lyplg_type_compare_simple,
         .plugin.sort = lyplg_type_sort_simple,
         .plugin.print = lyplg_type_print_node_instanceid,
         .plugin.duplicate = lyplg_type_dup_node_instanceid,
         .plugin.free = lyplg_type_free_instanceid,
-        .plugin.lyb_data_len = -1,
     },
     {0}
 };
