@@ -37,6 +37,7 @@
 #include "schema_features.h"
 #include "set.h"
 #include "tree.h"
+#include "tree_data_internal.h"
 #include "tree_edit.h"
 #include "tree_schema.h"
 #include "tree_schema_internal.h"
@@ -717,7 +718,7 @@ lys_parse_localfile(struct ly_ctx *ctx, const char *name, const char *revision,
     *found = 0;
     *result = NULL;
 
-    LY_CHECK_RET(lys_search_localfile(ly_ctx_get_searchdirs(ctx), !(ctx->flags & LY_CTX_DISABLE_SEARCHDIR_CWD), name,
+    LY_CHECK_RET(lys_search_localfile(ly_ctx_get_searchdirs(ctx), !(ctx->opts & LY_CTX_DISABLE_SEARCHDIR_CWD), name,
             revision, &filepath, &format));
     if (!filepath) {
         LOGVRB("Module \"%s%s%s\" not found in local searchdirs.", name, revision ? "@" : "", revision ? revision : "");
@@ -787,7 +788,7 @@ lys_load_mod_from_clb_or_file(struct ly_ctx *ctx, const char *name, const char *
         clb_used = 0;
     }
 
-    if (ctx->flags & LY_CTX_DISABLE_SEARCHDIRS) {
+    if (ctx->opts & LY_CTX_DISABLE_SEARCHDIRS) {
         /* searchdirs disabled */
         searchdirs_used = 1;
     } else if (mod_latest && (mod_latest->latest_revision & LYS_MOD_LATEST_SEARCHDIRS)) {
@@ -798,7 +799,7 @@ lys_load_mod_from_clb_or_file(struct ly_ctx *ctx, const char *name, const char *
     }
 
     while (!found && (!clb_used || !searchdirs_used)) {
-        if ((!(ctx->flags & LY_CTX_PREFER_SEARCHDIRS) || searchdirs_used) && !clb_used) {
+        if ((!(ctx->opts & LY_CTX_PREFER_SEARCHDIRS) || searchdirs_used) && !clb_used) {
             if (!ctx->imp_clb(name, revision, NULL, NULL, ctx->imp_clb_data, &format, &module_data, &module_data_free)) {
                 /* parse the module returned by the callback */
                 LY_CHECK_RET(ly_in_new_memory(module_data, &in));
@@ -1161,7 +1162,7 @@ lysp_load_submod_from_clb_or_file(struct lysp_ctx *pctx, const char *name, const
         clb_used = 0;
     }
 
-    if (ctx->flags & LY_CTX_DISABLE_SEARCHDIRS) {
+    if (ctx->opts & LY_CTX_DISABLE_SEARCHDIRS) {
         /* searchdirs disabled */
         searchdirs_used = 1;
     } else {
@@ -1169,7 +1170,7 @@ lysp_load_submod_from_clb_or_file(struct lysp_ctx *pctx, const char *name, const
     }
 
     while (!found && (!clb_used || !searchdirs_used)) {
-        if ((!(ctx->flags & LY_CTX_PREFER_SEARCHDIRS) || searchdirs_used) && !clb_used) {
+        if ((!(ctx->opts & LY_CTX_PREFER_SEARCHDIRS) || searchdirs_used) && !clb_used) {
             if (!ctx->imp_clb(PARSER_CUR_PMOD(pctx)->mod->name, NULL, name, revision, ctx->imp_clb_data, &format,
                     &submodule_data, &submodule_data_free)) {
                 /* parse the submodule returned by the callback */
@@ -2256,7 +2257,7 @@ lysp_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instanc
         struct lysp_ext **ext_def)
 {
     const char *tmp, *name, *prefix;
-    size_t pref_len, name_len;
+    uint32_t pref_len, name_len;
     LY_ARRAY_COUNT_TYPE u, v;
     const struct lys_module *mod = NULL;
     const struct lysp_submodule *submod;
@@ -2270,11 +2271,14 @@ lysp_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instanc
     ly_parse_nodeid(&tmp, &prefix, &pref_len, &name, &name_len);
 
     /* get module where the extension definition should be placed */
-    *ext_mod = mod = ly_resolve_prefix(ctx, prefix, pref_len, ext->format, ext->prefix_data);
+    mod = ly_resolve_prefix(ctx, prefix, pref_len, ext->format, ext->prefix_data);
     if (!mod) {
         LOGVAL(ctx, LYVE_REFERENCE, "Invalid prefix \"%.*s\" used for extension instance identifier.", (int)pref_len, prefix);
         return LY_EVALID;
     }
+    if (ext_mod) {
+        *ext_mod = mod;
+    }
 
     if (!ext_def) {
         /* we are done */
@@ -2309,11 +2313,49 @@ lysp_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instanc
 }
 
 LY_ERR
-lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance *ext_p)
+lysc_ext_find_definition(const struct ly_ctx *ctx, const struct lysp_ext_instance *ext, struct lysc_ext **ext_def)
 {
-    assert(ext_p->def);
+    const char *tmp, *name, *prefix;
+    uint32_t pref_len, name_len;
+    LY_ARRAY_COUNT_TYPE u;
+    const struct lys_module *mod = NULL;
 
-    if (!ext_p->def->argname || ext_p->argument) {
+    *ext_def = NULL;
+
+    /* parse the prefix, the nodeid was previously already parsed and checked */
+    tmp = ext->name;
+    ly_parse_nodeid(&tmp, &prefix, &pref_len, &name, &name_len);
+
+    /* get module where the extension definition should be placed */
+    mod = ly_resolve_prefix(ctx, prefix, pref_len, ext->format, ext->prefix_data);
+    if (!mod) {
+        LOGVAL(ctx, LYVE_REFERENCE, "Invalid prefix \"%.*s\" used for extension instance identifier.", (int)pref_len, prefix);
+        return LY_EVALID;
+    }
+
+    /* find the compiled extension definition there */
+    LY_ARRAY_FOR(mod->extensions, u) {
+        if (!strcmp(name, mod->extensions[u].name)) {
+            *ext_def = &mod->extensions[u];
+            break;
+        }
+    }
+
+    if (!*ext_def) {
+        LOGVAL(ctx, LYVE_REFERENCE, "Extension definition of extension instance \"%s\" not found.", ext->name);
+        return LY_EVALID;
+    }
+
+    return LY_SUCCESS;
+}
+
+LY_ERR
+lysp_ext_instance_resolve_argument(const struct ly_ctx *ctx, const struct lysp_ext *ext_def, struct lysp_ext_instance *ext_p)
+{
+    const char *ext, *arg, *prefix_arg, *name_arg, *prefix_ext, *name_ext;
+    uint32_t prefix_arg_len, name_arg_len, prefix_ext_len, name_ext_len;
+
+    if (!ext_def->argname || ext_p->argument) {
         /* nothing to do */
         return LY_SUCCESS;
     }
@@ -2322,20 +2364,17 @@ lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance
         /* schema was parsed from YIN and an argument is expected, ... */
         struct lysp_stmt *stmt = NULL;
 
-        if (ext_p->def->flags & LYS_YINELEM_TRUE) {
+        if (ext_def->flags & LYS_YINELEM_TRUE) {
             /* ... argument was the first XML child element */
             for (stmt = ext_p->child; stmt && (stmt->flags & LYS_YIN_ATTR); stmt = stmt->next) {}
             if (stmt) {
-                const char *arg, *ext, *name_arg, *name_ext, *prefix_arg, *prefix_ext;
-                size_t name_arg_len, name_ext_len, prefix_arg_len, prefix_ext_len;
-
                 stmt = ext_p->child;
 
                 arg = stmt->stmt;
                 ly_parse_nodeid(&arg, &prefix_arg, &prefix_arg_len, &name_arg, &name_arg_len);
-                if (ly_strncmp(ext_p->def->argname, name_arg, name_arg_len)) {
+                if (ly_strncmp(ext_def->argname, name_arg, name_arg_len)) {
                     LOGVAL(ctx, LYVE_SEMANTICS, "Extension instance \"%s\" expects argument element \"%s\" as its first XML child, "
-                            "but \"%.*s\" element found.", ext_p->name, ext_p->def->argname, (int)name_arg_len, name_arg);
+                            "but \"%.*s\" element found.", ext_p->name, ext_def->argname, (int)name_arg_len, name_arg);
                     return LY_EVALID;
                 }
 
@@ -2347,14 +2386,14 @@ lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance
                 if (ly_resolve_prefix(ctx, prefix_ext, prefix_ext_len, ext_p->format, ext_p->prefix_data) !=
                         ly_resolve_prefix(ctx, prefix_arg, prefix_arg_len, stmt->format, stmt->prefix_data)) {
                     LOGVAL(ctx, LYVE_SEMANTICS, "Extension instance \"%s\" element and its argument element \"%s\" are "
-                            "expected in the same namespace, but they differ.", ext_p->name, ext_p->def->argname);
+                            "expected in the same namespace, but they differ.", ext_p->name, ext_def->argname);
                     return LY_EVALID;
                 }
             }
         } else {
             /* ... argument was one of the XML attributes which are represented as child stmt with LYS_YIN_ATTR flag */
             for (stmt = ext_p->child; stmt && (stmt->flags & LYS_YIN_ATTR); stmt = stmt->next) {
-                if (!strcmp(stmt->stmt, ext_p->def->argname)) {
+                if (!strcmp(stmt->stmt, ext_def->argname)) {
                     /* this is the extension's argument */
                     break;
                 }
@@ -2362,7 +2401,7 @@ lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance
         }
 
         if (stmt) {
-            LY_CHECK_RET(lydict_insert(ctx, stmt->arg, 0, &ext_p->argument));
+            LY_CHECK_RET(lysdict_insert(ctx, stmt->arg, 0, &ext_p->argument));
             stmt->flags |= LYS_YIN_ARGUMENT;
         }
     }
@@ -2370,7 +2409,7 @@ lysp_ext_instance_resolve_argument(struct ly_ctx *ctx, struct lysp_ext_instance
     if (!ext_p->argument) {
         /* missing extension's argument */
         LOGVAL(ctx, LYVE_SEMANTICS, "Extension instance \"%s\" missing argument %s\"%s\".",
-                ext_p->name, (ext_p->def->flags & LYS_YINELEM_TRUE) ? "element " : "", ext_p->def->argname);
+                ext_p->name, (ext_def->flags & LYS_YINELEM_TRUE) ? "element " : "", ext_def->argname);
         return LY_EVALID;
     }
 
@@ -2813,3 +2852,22 @@ lys_stmt_flags(enum ly_stmt stmt)
 
     return 0;
 }
+
+int
+lysc_value_cmp(const struct lysc_node *schema, const struct lyd_node *ctx_node, const struct lysc_value *val,
+        const char *val2)
+{
+    LY_ERR r;
+    int cmp;
+    const char *canon;
+
+    r = lyd_value_validate3(schema, val->str, strlen(val->str), LY_VALUE_SCHEMA_RESOLVED, val->prefixes,
+            LYD_HINT_SCHEMA, ctx_node, NULL, 1, NULL, &canon);
+    if (r && (r != LY_EINCOMPLETE)) {
+        return -1;
+    }
+
+    cmp = strcmp(canon, val2);
+    lydict_remove(schema->module->ctx, canon);
+    return cmp;
+}
