@@ -73,7 +73,7 @@
         char *xml_out, *data; \
         data = "<" NODE_NAME " xmlns=\"urn:tests:" MOD_NAME "\">" DATA "</" NODE_NAME ">"; \
         CHECK_PARSE_LYD_PARAM(data, LYD_XML, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, LY_SUCCESS, tree_1); \
-        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_WITHSIBLINGS), 0); \
+        assert_int_equal(lyd_print_mem(&xml_out, tree_1, LYD_LYB, LYD_PRINT_SIBLINGS), 0); \
         assert_int_equal(LY_SUCCESS, lyd_parse_data_mem(UTEST_LYCTX, xml_out, LYD_LYB, LYD_PARSE_ONLY | LYD_PARSE_STRICT, 0, &tree_2)); \
         assert_non_null(tree_2); \
         CHECK_LYD(tree_1, tree_2); \
@@ -421,7 +421,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 1);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "20", 20);
+    assert_string_equal(lysc_leaf->dflt.str, "20");
     range = ((struct lysc_type_num *)lysc_leaf->type)->range;
     CHECK_LYSC_RANGE(range, NULL, NULL, NULL, 0, 2, NULL);
     assert_int_equal(range->parts[0].min_64, 0);
@@ -441,7 +441,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 1);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "127", 127);
+    assert_string_equal(lysc_leaf->dflt.str, "127");
     range = ((struct lysc_type_num *)lysc_leaf->type)->range;
     CHECK_LYSC_RANGE(range, NULL, NULL, NULL, 0, 2, NULL);
     assert_int_equal(range->parts[0].min_64, 0);
@@ -502,7 +502,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "15", 15);
+    assert_string_equal(lysc_leaf->dflt.str, "0xf");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "0xf");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -518,7 +518,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "-15", -15);
+    assert_string_equal(lysc_leaf->dflt.str, "-0xf");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "-0xf");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -534,7 +534,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 1);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "127", 127);
+    assert_string_equal(lysc_leaf->dflt.str, "+0x7F");
     range = ((struct lysc_type_num *)lysc_leaf->type)->range;
     CHECK_LYSC_RANGE(range, NULL, NULL, NULL, 0, 2, NULL);
     assert_int_equal(range->parts[0].min_64, 0);
@@ -587,7 +587,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "15", 15);
+    assert_string_equal(lysc_leaf->dflt.str, "017");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "017");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -603,7 +603,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "-15", -15);
+    assert_string_equal(lysc_leaf->dflt.str, "-017");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "-017");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -619,7 +619,7 @@ test_schema_yang(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "15", 15);
+    assert_string_equal(lysc_leaf->dflt.str, "+017");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "+017");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -842,7 +842,7 @@ test_schema_yin(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 1);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "12", 12);
+    assert_string_equal(lysc_leaf->dflt.str, "12");
     range = ((struct lysc_type_num *)lysc_leaf->type)->range;
     CHECK_LYSC_RANGE(range, NULL, NULL, NULL, 0, 2, NULL);
     assert_int_equal(range->parts[0].min_64, -128);
@@ -899,7 +899,7 @@ test_schema_yin(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "15", 15);
+    assert_string_equal(lysc_leaf->dflt.str, "+0xf");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "+0xf");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -915,7 +915,7 @@ test_schema_yin(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "-15", -15);
+    assert_string_equal(lysc_leaf->dflt.str, "-0xf");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "-0xf");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -961,7 +961,7 @@ test_schema_yin(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "15", 15);
+    assert_string_equal(lysc_leaf->dflt.str, "+017");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "+017");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -977,7 +977,7 @@ test_schema_yin(void **state)
     lysc_leaf = (void *)mod->compiled->data;
     CHECK_LYSC_NODE_LEAF(lysc_leaf, NULL, 0, 0x205, 1, "port", 0, 0, 0, NULL, 0, 0, NULL, 1);
     CHECK_LYSC_TYPE_NUM((struct lysc_type_num *)lysc_leaf->type, LY_TYPE_INT8, 0, 0);
-    CHECK_LYD_VALUE(*(lysc_leaf->dflt), INT8, "-15", -15);
+    assert_string_equal(lysc_leaf->dflt.str, "-017");
     lysp_leaf = (void *)mod->parsed->data;
     CHECK_LYSP_NODE_LEAF(lysp_leaf, NULL, 0, 0x0, 0, "port", 0, 0, NULL, 0, 0, NULL, "-017");
     CHECK_LYSP_TYPE(&(lysp_leaf->type), 0, 0, 0, 0, 0, 0x0, 0, 0, "int8", 0, 0, 1, 0, 0, 0);
@@ -1309,7 +1309,7 @@ test_diff(void **state)
     LYD_TREE_CREATE(data_2, model_2);
     assert_int_equal(LY_SUCCESS, lyd_diff_siblings(model_1, model_2, 0, &diff));
     assert_non_null(diff);
-    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&model_1, diff));
     CHECK_LYD(model_1, model_2);
     lyd_free_all(model_1);
@@ -1327,7 +1327,7 @@ test_diff(void **state)
     assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&model_1, diff));
     expected_string = "<port xmlns=\"urn:tests:defs\">120</port>";
 
-    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     lyd_free_all(model_1);
     lyd_free_all(diff);
 
@@ -1359,7 +1359,7 @@ test_diff(void **state)
     LYD_TREE_CREATE(data_2, model_2);
     assert_int_equal(LY_SUCCESS, lyd_diff_siblings(model_1, model_2, 0, &diff));
     assert_non_null(diff);
-    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(diff, diff_expected, LYD_XML, LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
     assert_int_equal(LY_SUCCESS, lyd_diff_apply_all(&model_1, diff));
     CHECK_LYD(model_1, model_2);
     lyd_free_all(diff);
@@ -1383,11 +1383,11 @@ test_print(void **state)
 
     /* XML */
     expected_string = "<port xmlns=\"urn:tests:defs\">50</port>";
-    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_XML, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
 
     /* JSON */
     expected_string = "{\"defs:port\":50}";
-    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_WITHSIBLINGS | LYD_PRINT_SHRINK);
+    CHECK_LYD_STRING_PARAM(model_1, expected_string, LYD_JSON, LYD_PRINT_SHRINK | LYD_PRINT_SIBLINGS | LYD_PRINT_SHRINK);
 
     lyd_free_all(model_1);
 }
@@ -1399,7 +1399,7 @@ test_plugin_store(void **state)
     struct ly_err_item *err = NULL;
     struct lys_module *mod;
     struct lyd_value value = {0};
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]));
     struct lysc_type *lysc_type;
     LY_ERR ly_ret;
     char *alloc;
@@ -1412,61 +1412,61 @@ test_plugin_store(void **state)
     lysc_type = ((struct lysc_node_leaf *)mod->compiled->data)->type;
 
     /* check proper type */
-    assert_string_equal("libyang 2 - integers, version 1", type->id);
+    assert_string_equal("ly2 integers", type->id);
 
     /* check store
      * options = LY_TYPE_STORE_IMPLEMENT | LY_TYPE_STORE_DYNAMIC
      * hint    = LYD_VALHINT_DECNUM, LYD_VALHINT_HEXNUM, LYD_VALHINT_OCTNUM
      */
     val_text = "20";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, INT8, "20", 20);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "-20";
-    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &value, NULL, &err));
+    assert_int_equal(LY_SUCCESS, type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &value, NULL, &err));
     CHECK_LYD_VALUE(value, INT8, "-20", -20);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "0xf";
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "15", 15);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "1B";
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "27", 27);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "-0xf";
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "-15", -15);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "027";
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "23", 23);
     assert_ptr_equal(value.realtype, lysc_type);
     type->free(UTEST_LYCTX, &value);
 
     val_text = "-027";
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_OCTNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "-23", -23);
     assert_ptr_equal(value.realtype, lysc_type);
@@ -1480,8 +1480,8 @@ test_plugin_store(void **state)
     alloc = (char *)malloc(strlen(val_text) + 1);
 
     memcpy(alloc, val_text, strlen(val_text) + 1);
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, alloc, strlen(val_text),
-            LYPLG_TYPE_STORE_DYNAMIC, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, alloc, strlen(val_text) * 8,
+            LYPLG_TYPE_STORE_DYNAMIC, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     alloc = NULL;
     assert_int_equal(LY_SUCCESS, ly_ret);
     CHECK_LYD_VALUE(value, INT8, "10", 10);
@@ -1491,8 +1491,8 @@ test_plugin_store(void **state)
     lysc_type_test = *lysc_type;
     lysc_type_test.basetype = LY_TYPE_UINT8;
     val_text = "20";
-    ly_ret = type->store(UTEST_LYCTX, &lysc_type_test, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, &lysc_type_test, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EINT, ly_ret);
     UTEST_LOG_CTX_CLEAN;
 
@@ -1501,38 +1501,38 @@ test_plugin_store(void **state)
      */
     val_text = "";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     val_text = "";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, 1,
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, 1 * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     val_text = "10 b";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     val_text = "a";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &value, NULL, &err);
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &value, NULL, &err);
     assert_int_equal(LY_EVALID, ly_ret);
     ly_err_free(err);
 
     /* LYPLG_TYPE_STORE_ONLY test */
     val_text = "-60";
     err = NULL;
-    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text),
+    ly_ret = type->store(UTEST_LYCTX, lysc_type, val_text, strlen(val_text) * 8,
             LYPLG_TYPE_STORE_ONLY, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL,
-            &value, NULL, &err);
+            NULL, &value, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     type->free(UTEST_LYCTX, &value);
     ly_err_free(err);
@@ -1546,7 +1546,7 @@ test_plugin_compare(void **state)
     struct ly_err_item *err = NULL;
     struct lys_module *mod;
     struct lyd_value values[10];
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]));
     struct lysc_type *lysc_type;
     LY_ERR ly_ret;
     const char *schema;
@@ -1568,8 +1568,8 @@ test_plugin_compare(void **state)
 
     /* CREATE VALUES */
     for (unsigned int it = 0; it < sizeof(val_init) / sizeof(val_init[0]); it++) {
-        ly_ret = type->store(UTEST_LYCTX, lysc_type, val_init[it], strlen(val_init[it]),
-                0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &(values[it]), NULL, &err);
+        ly_ret = type->store(UTEST_LYCTX, lysc_type, val_init[it], strlen(val_init[it]) * 8,
+                0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &(values[it]), NULL, &err);
         assert_int_equal(LY_SUCCESS, ly_ret);
     }
 
@@ -1588,8 +1588,8 @@ test_plugin_compare(void **state)
      */
     diff_type_text = "20";
     diff_type = ((struct lysc_node_leaf *)mod->compiled->data->next)->type;
-    ly_ret = diff_type->plugin->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &diff_type_val, NULL, &err);
+    ly_ret = lysc_get_type_plugin(diff_type->plugin_ref)->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &diff_type_val, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     assert_int_equal(LY_SUCCESS, type->compare(UTEST_LYCTX, &diff_type_val, &(values[0])));
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[1])));
@@ -1600,8 +1600,8 @@ test_plugin_compare(void **state)
      */
     diff_type_text = "20";
     diff_type = ((struct lysc_node_leaf *)mod->compiled->data->next->next)->type;
-    ly_ret = diff_type->plugin->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &diff_type_val, NULL, &err);
+    ly_ret = lysc_get_type_plugin(diff_type->plugin_ref)->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &diff_type_val, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[0])));
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[1])));
@@ -1612,8 +1612,8 @@ test_plugin_compare(void **state)
      */
     diff_type_text = "20";
     diff_type = ((struct lysc_node_leaf *)mod->compiled->data->next->next->next)->type;
-    ly_ret = diff_type->plugin->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text),
-            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, &diff_type_val, NULL, &err);
+    ly_ret = lysc_get_type_plugin(diff_type->plugin_ref)->store(UTEST_LYCTX, diff_type, diff_type_text, strlen(diff_type_text) * 8,
+            0, LY_VALUE_XML, NULL, LYD_VALHINT_DECNUM, NULL, NULL, &diff_type_val, NULL, &err);
     assert_int_equal(LY_SUCCESS, ly_ret);
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[0])));
     assert_int_equal(LY_ENOT, type->compare(UTEST_LYCTX, &diff_type_val, &(values[1])));
@@ -1631,7 +1631,7 @@ test_plugin_print(void **state)
     struct ly_err_item *err = NULL;
     struct lys_module *mod;
     struct lyd_value values[10];
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]));
     struct lysc_type *lysc_type;
     LY_ERR ly_ret;
     const char *schema;
@@ -1645,8 +1645,8 @@ test_plugin_print(void **state)
 
     /* CREATE VALUES */
     for (unsigned int it = 0; it < sizeof(val_init) / sizeof(val_init[0]); it++) {
-        ly_ret = type->store(UTEST_LYCTX, lysc_type, val_init[it], strlen(val_init[it]),
-                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &(values[it]), NULL, &err);
+        ly_ret = type->store(UTEST_LYCTX, lysc_type, val_init[it], strlen(val_init[it]) * 8,
+                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &(values[it]), NULL, &err);
         assert_int_equal(LY_SUCCESS, ly_ret);
     }
 
@@ -1671,7 +1671,7 @@ test_plugin_dup(void **state)
     struct ly_err_item *err = NULL;
     struct lys_module *mod;
     struct lyd_value values[10];
-    struct lyplg_type *type = lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]);
+    struct lyplg_type *type = lysc_get_type_plugin(lyplg_type_plugin_find(NULL, "", NULL, ly_data_type2str[LY_TYPE_INT8]));
     struct lysc_type *lysc_type[2];
     const char *schema;
     LY_ERR ly_ret;
@@ -1693,8 +1693,8 @@ test_plugin_dup(void **state)
 
     /* CREATE VALUES */
     for (unsigned int it = 0; it < sizeof(val_init) / sizeof(val_init[0]); it++) {
-        ly_ret = type->store(UTEST_LYCTX, lysc_type[it % 2], val_init[it], strlen(val_init[it]),
-                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, &(values[it]), NULL, &err);
+        ly_ret = type->store(UTEST_LYCTX, lysc_type[it % 2], val_init[it], strlen(val_init[it]) * 8,
+                0, LY_VALUE_XML, NULL, LYD_VALHINT_HEXNUM, NULL, NULL, &(values[it]), NULL, &err);
         assert_int_equal(LY_SUCCESS, ly_ret);
     }
 
