@@ -49,7 +49,7 @@ cmd_data_help_type(void)
 {
     printf("  -t TYPE, --type=TYPE\n"
             "                Specify data tree type in the input data file(s):\n"
-            "        data          - Complete datastore with status data (default type).\n"
+            "        data          - Complete (operational) datastore with state data (default).\n"
             "        config        - Configuration datastore (without status data).\n"
             "        get           - Result of the NETCONF <get> operation.\n"
             "        getconfig     - Result of the NETCONF <get-config> operation.\n"
@@ -180,7 +180,7 @@ cmd_data_opt(struct yl_opt *yo, const char *cmdline, char ***posv, int *posc)
     uint8_t data_type_set = 0;
 
     yo->data_parse_options = YL_DEFAULT_DATA_PARSE_OPTIONS;
-    yo->data_validate_options = YL_DEFAULT_DATA_VALIDATE_OPTIONS;
+    yo->data_validate_options = YL_DEFAULT_DATA_VALIDATE_OPTIONS | LYD_VALIDATE_OPERATIONAL;
 
     if ((rc = parse_cmdline(cmdline, &argc, &yo->argv))) {
         return rc;
@@ -219,14 +219,14 @@ cmd_data_opt(struct yl_opt *yo, const char *cmdline, char ***posv, int *posc)
                 }
             }
             break;
-        case 'O':   /* --operational */
+        case 'O': /* --operational */
             if (yo->data_operational.path) {
                 YLMSG_E("The operational datastore (-O) cannot be set multiple times.");
                 return 1;
             }
             yo->data_operational.path = optarg;
             break;
-        case 'R':   /* --reply-rpc */
+        case 'R': /* --reply-rpc */
             if (yo->reply_rpc.path) {
                 YLMSG_E("The PRC of the reply (-R) cannot be set multiple times.");
                 return 1;
@@ -594,11 +594,11 @@ parse_input_by_type(struct ly_ctx *ctx, enum lyd_type type, struct cmdline_file
     case LYD_TYPE_RPC_YANG:
     case LYD_TYPE_REPLY_YANG:
     case LYD_TYPE_NOTIF_YANG:
-        ret = lyd_parse_op(ctx, NULL, input_f->in, input_f->format, type, tree, op);
+        ret = lyd_parse_op(ctx, NULL, input_f->in, input_f->format, type, LYD_PARSE_STRICT, tree, op);
         break;
     case LYD_TYPE_RPC_NETCONF:
     case LYD_TYPE_NOTIF_NETCONF:
-        ret = lyd_parse_op(ctx, NULL, input_f->in, input_f->format, type, &envp, op);
+        ret = lyd_parse_op(ctx, NULL, input_f->in, input_f->format, type, LYD_PARSE_STRICT, &envp, op);
 
         /* adjust pointers */
         for (*tree = *op; lyd_parent(*tree); *tree = lyd_parent(*tree)) {}
@@ -606,7 +606,8 @@ parse_input_by_type(struct ly_ctx *ctx, enum lyd_type type, struct cmdline_file
     case LYD_TYPE_REPLY_NETCONF:
         /* parse source RPC operation */
         assert(reply_rpc && reply_rpc->in);
-        ret = lyd_parse_op(ctx, NULL, reply_rpc->in, reply_rpc->format, LYD_TYPE_RPC_NETCONF, &envp, op);
+        ret = lyd_parse_op(ctx, NULL, reply_rpc->in, reply_rpc->format, LYD_TYPE_RPC_NETCONF, LYD_PARSE_STRICT,
+                &envp, op);
         if (ret) {
             YLMSG_E("Failed to parse source NETCONF RPC operation file \"%s\".", reply_rpc->path);
             goto cleanup;
@@ -622,7 +623,7 @@ parse_input_by_type(struct ly_ctx *ctx, enum lyd_type type, struct cmdline_file
         lyd_free_all(envp);
         envp = NULL;
 
-        ret = lyd_parse_op(ctx, *op, input_f->in, input_f->format, type, &envp, NULL);
+        ret = lyd_parse_op(ctx, *op, input_f->in, input_f->format, type, LYD_PARSE_STRICT, &envp, NULL);
         break;
     default:
         YLMSG_E("Internal error (%s:%d).", __FILE__, __LINE__);
@@ -650,9 +651,6 @@ parse_ext_inst_data(struct ly_ctx *ctx, struct yl_opt *yo, struct cmdline_file *
         struct lyd_node *oper_tree, struct lyd_node **tree)
 {
     LY_ERR ret = LY_SUCCESS;
-    struct ly_set tree_nodes = {0};
-    struct lyd_node *iter;
-    uint32_t i;
 
     if (find_extension(ctx, yo)) {
         YLMSG_E("Extension '%s:%s:%s' not found in module.", yo->mod_name, yo->name, yo->argument);
@@ -669,31 +667,10 @@ parse_ext_inst_data(struct ly_ctx *ctx, struct yl_opt *yo, struct cmdline_file *
         return LY_EDENIED;
     }
 
-    if (oper_tree) {
-        /* remember data top-level nodes */
-        LY_LIST_FOR(*tree, iter) {
-            ly_set_add(&tree_nodes, iter, 1, NULL);
-        }
-
-        /* connect data with operational data for validation */
-        lyd_insert_sibling(*tree, oper_tree, tree);
-        ret = lyd_validate_all(tree, ctx, yo->data_validate_options, NULL);
-
-        /* disconnect data and operational data */
-        *tree = NULL;
-        for (i = 0; i < tree_nodes.count; ++i) {
-            iter = tree_nodes.dnodes[i];
-            lyd_unlink_tree(iter);
-            lyd_insert_sibling(*tree, iter, tree);
-        }
-    } else {
-        /* validate extension instance data */
-        ret = lyd_validate_all(tree, ctx, yo->data_validate_options, NULL);
-    }
+    /* validate extension instance data */
+    ret = lyd_validate_ext(tree, yo->ext, yo->data_validate_options, oper_tree, NULL);
 
     yo->data_ext = 0;
-
-    ly_set_erase(&tree_nodes, NULL);
     return ret;
 }
 
