@@ -3,7 +3,7 @@
  * @author Michal Vasko <mvasko@cesnet.cz>
  * @brief libyang's yanglint tool auto completion
  *
- * Copyright (c) 2015 CESNET, z.s.p.o.
+ * Copyright (c) 2015 - 2025 CESNET, z.s.p.o.
  *
  * This source code is licensed under BSD 3-Clause License (the "License").
  * You may not use this file except in compliance with the License.
@@ -13,7 +13,9 @@
  */
 
 #define _GNU_SOURCE
-#define _POSIX_C_SOURCE 200809L /* strdup */
+#if !defined (__FreeBSD__) /* hides asprintf */
+# define _POSIX_C_SOURCE 200809L /* strdup */
+#endif
 
 #include <dirent.h>
 #include <errno.h>
